{pkgs, ...}: let
  username = "jolheiser";
in {
  imports = [./hardware.nix ../common/gui];

  boot = {
    kernelPackages = pkgs.linuxPackages_latest;
    kernelParams = ["quiet" "splash"];
    loader.efi.canTouchEfiVariables = true;
    loader.systemd-boot.enable = true;
    initrd.systemd.enable = true;
  };

  hardware = {bluetooth.enable = true;};

  networking = {
    hostName = "chai";
    networkmanager.enable = true;
    firewall.enable = true;
  };

  boot.initrd.luks.devices = {
    "luks-83586073-35f8-438d-9203-99f1e966c2ca" = {
      device = "/dev/disk/by-uuid/83586073-35f8-438d-9203-99f1e966c2ca";
      keyFile = "/crypto_keyfile.bin";
    };
  };

  services = {
    blueman.enable = true;
    pcscd.enable = true;
    openssh = {
      enable = true;
      settings = {X11Forwarding = true;};
    };
    globalprotect.enable = true;
    printing = {
      enable = true;
      drivers = [pkgs.hplip];
    };
  };

  virtualisation.docker.enable = true;

  users.users."${username}" = {
    extraGroups = ["wheel" "docker"];
    isNormalUser = true;
  };

  environment.systemPackages = with pkgs; [
    globalprotect-openconnect
    jetbrains.pycharm-professional
    jetbrains.idea-ultimate
    jetbrains.datagrip
    libxcrypt
    py39.python39
    py39.python39Packages.virtualenv
    py39.python39Packages.psycopg2
    py39.python39Packages.wheel
    py39.python39Packages.setuptools
    py39.python39Packages.pip
    python3Packages.twine
    subversion
    teams-for-linux
    xorg.xauth

    # Flake overlay
    jolheiser.nur.prospect-mail
  ];

  system.stateVersion = "22.11";
}
